@@ -24,7 +24,7 @@
 #define EXTRACTIONRESULT_H
 
 #include <KFileMetaData/ExtractionResult>
-#include <xapian.h>
+#include "xapiantermgenerator.h"
 
 class Result : public KFileMetaData::ExtractionResult
 {
@@ -36,12 +36,6 @@ public:
     virtual void append(const QString& text);
     virtual void addType(KFileMetaData::Type::Type type);
 
-    /**
-     * Read only mode is a special mode where plain text changes are ignored
-     * so this way, this class will consume less memory
-     */
-    void setReadOnly(bool readOnly);
-
     void setId(uint id);
     void setDocument(const Xapian::Document& doc);
 
@@ -61,11 +55,10 @@ public:
 private:
     uint m_docId;
     Xapian::Document m_doc;
-    Xapian::TermGenerator m_termGen;
-    Xapian::TermGenerator m_termGenForText;
+    Baloo::XapianTermGenerator m_termGen;
+    Baloo::XapianTermGenerator m_termGenForText;
 
     QVariantMap m_map;
-    bool m_readOnly;
 };
 
 #endif // EXTRACTIONRESULT_H
