@@ -36,7 +36,7 @@ class FileIndexerConfig;
 class FileIndexer : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.baloo.file")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.baloo")
 
 public:
     FileIndexer(Database* db, FileIndexerConfig* config, QObject* parent = 0);
@@ -81,7 +81,7 @@ public Q_SLOTS:
     /**
      * Index a folder independent of its configuration status.
      */
-    Q_SCRIPTABLE void indexFolder(const QString& path, bool recursive, bool forced);
+    Q_SCRIPTABLE void indexFolder(const QString& path, bool forced);
 
     /**
      * Index a specific file
